pub enum MetaValue {
None,
Bool(bool),
Int(i64),
Str(Arc<str>),
List(Vec<MetaValue>),
Tuple(Vec<MetaValue>),
Map(BTreeMap<String, MetaValue>),
}Expand description
Structured metadata values (used by Textual handlers and richer annotations).
This is intentionally deterministic and Eq so it can be compared / merged
and used in segment simplification.
Variants
None
Bool(bool)
Int(i64)
Str(Arc<str>)
List(Vec<MetaValue>)
Tuple(Vec<MetaValue>)
Map(BTreeMap<String, MetaValue>)
Implementations
Sourceimpl MetaValue
impl MetaValue
pub fn str(value: impl Into<Arc<str>>) -> Self
Sourcepub fn parse_python_literal(input: &str) -> Option<Self>
pub fn parse_python_literal(input: &str) -> Option<Self>
Parse a small, deterministic subset of Python literals (like ast.literal_eval).
Supported:
None,True,False- integers (base-10)
- quoted strings
'...'/"..."with basic escapes - lists
[a, b] - tuples
(a, b)(single element tuples require a trailing comma, like Python) - dicts
{'k': 1}(string keys only)