Layout

Struct Layout 

pub struct Layout { /* private fields */ }
A renderable that divides a fixed height in to rows or columns.

Implementations

Source

impl Layout

pub fn new() -> Self

Create a new Layout with a placeholder renderable.

pub fn with_renderable(renderable: impl Renderable + 'static) -> Self

Create a new leaf layout with a renderable.

pub fn with_name(self, name: impl Into<String>) -> Self

pub fn with_size(self, size: usize) -> Self

pub fn with_minimum_size(self, minimum_size: usize) -> Self

pub fn with_ratio(self, ratio: usize) -> Self

pub fn with_visible(self, visible: bool) -> Self

pub fn id(&self) -> usize

pub fn name(&self) -> Option<String>

pub fn children(&self) -> Vec<Layout>

pub fn get(&self, name: &str) -> Option<Layout>

pub fn update(&self, renderable: impl Renderable + 'static)

pub fn split(&self, splitter: SplitterKind, layouts: Vec<Layout>)

pub fn split_row(&self, layouts: Vec<Layout>)

pub fn split_column(&self, layouts: Vec<Layout>)

pub fn add_split(&self, layouts: Vec<Layout>)

pub fn unsplit(&self)

pub fn refresh_screen( &self, console: &mut Console<Stdout>, layout_name: &str, ) -> Result<()>

Refresh a sub-layout in an alternate screen.

This matches Rich’s Layout.refresh_screen behavior and requires alt-screen mode.

Source

impl Layout

pub fn to_tree(&self) -> Tree

Build a Tree renderable that visualises the layout hierarchy.

This matches Python Rich’s Layout.tree property: each node shows the layout name (or “”), its splitter direction, and size/ratio info.