Screen

Struct Screen 

pub struct Screen { /* private fields */ }
A renderable that fills the terminal screen and crops excess.

Screen renders its content to fill the full terminal dimensions, cropping any excess and padding if needed.

Example

use rich_rs::{Console, Text};
use rich_rs::screen::Screen;

let text = Text::plain("Hello, World!");
let screen = Screen::new(text);

Implementations

Source

impl Screen

pub fn new(renderable: impl Renderable + 'static) -> Self

Create a new Screen with a renderable.

pub fn new_many<I, R>(renderables: I) -> Self
where I: IntoIterator<Item = R>, R: Renderable + 'static,

Create a new Screen from multiple renderables.

Python Rich’s Screen(*renderables) wraps the inputs in Group. This is the closest Rust equivalent.

pub fn from_arc(renderable: Arc<dyn Renderable>) -> Self

Create a new Screen from an Arc<dyn Renderable>.

This avoids an extra Arc allocation when you already have one.

pub fn with_style(self, style: impl Into<Style>) -> Self

Set the background style.

pub fn with_application_mode(self, mode: bool) -> Self

Enable application mode (uses \n\r newlines).

Application mode is typically used when the terminal is in alternate screen mode, where \n\r provides correct cursor positioning.