pub struct ProgressReader<'a, R: Read> { /* private fields */ }Expand description
A reader that tracks progress as bytes are read.
This wraps any type implementing Read and updates a progress task
as data is read. Similar to Python Rich’s _Reader class.
Example
ⓘ
use std::fs::File;
use std::io::Read;
use rich_rs::progress::{Progress, LiveOptions};
use rich_rs::live::LiveOptions;
let mut progress = Progress::new_default(LiveOptions::default(), false, false, false);
progress.start().unwrap();
let mut reader = progress.open("large_file.bin", "Reading...").unwrap();
let mut buffer = Vec::new();
reader.read_to_end(&mut buffer).unwrap();
progress.stop().unwrap();Implementations
Sourceimpl<'a, R: Read> ProgressReader<'a, R>
impl<'a, R: Read> ProgressReader<'a, R>
Sourcepub fn new(
inner: R,
progress: &'a Progress,
task_id: TaskID,
close_handle: bool,
) -> Self
pub fn new( inner: R, progress: &'a Progress, task_id: TaskID, close_handle: bool, ) -> Self
Create a new ProgressReader wrapping the given reader.
The close_handle parameter controls whether the inner reader
should be dropped when this wrapper is dropped (for owned handles).
Sourcepub fn into_inner(self) -> R
pub fn into_inner(self) -> R
Consumes the wrapper, returning the inner reader.